@@ -1,4 +1,4 @@
-__version__ = "0.0.9"
+__version__ = "0.1.2"
 
 import pathlib
 
@@ -7,9 +7,10 @@ from friendly_traceback import exclude_directory_from_traceback, config
 
 # The following import will automatically add relevant parsers to
 # those known by friendly_traceback
-from . import key_error
+from . import specific
+from . import generic
 
-print(f"friendly_pandas version {__version__}: pandas-specific exception handlers added.")
+print(f"friendly_pandas version {__version__}")
 
 # We want to focus on the code entered by the user.
 # We remove anything that occurs inside pandas' library from the traceback
